@@ -29,8 +29,20 @@ sub features {
 			 @args);
 }
 
+#required by GBrowse1
+sub get_feature_stream {
+    my $self = shift;
+    my @args = @_;
+
+    my @features = $self->features(@args);
+
+    return Bio::DB::Sam::Segment::Iterator->new(\@features);
+}
+
 # required by api
 sub seq_id   { shift->{seqid} };
+# required by GBrowse1
+*ref = *abs_ref = *sourceseq = \&seq_id;
 # required by api
 sub start    { shift->{start} };
 # required by api
@@ -75,6 +87,8 @@ sub factory { shift->db  }
 sub get_SeqFeatures { return;   }
 # required by api
 sub method { shift->primary_tag }
+# required by GBrowse1
+sub type { shift->primary_tag }
 # required by api
 sub get_tag_values {  return; }
 # required by api
@@ -82,4 +96,21 @@ sub score { return;  }
 # required by api
 sub class { 'sequence'  }
 
+
+
+package Bio::DB::Sam::Segment::Iterator;
+
+sub new {
+  my $package  = shift;
+  my $features = shift;
+  return bless $features,$package;
+}
+
+sub next_seq {
+  my $self = shift;
+  return unless @$self;
+    my $next_feature = shift @$self;
+  return $next_feature;
+}
+
 1;
